import { Observable } from 'rxjs';
import { NgxUiLoaderConfig } from './ngx-ui-loader-config';
export declare class NgxUiLoaderHelperService {
    private config;
    private defaultConfig;
    private waitingForeground;
    private waitingBackground;
    private fgTimeoutHandler;
    private bgTimeoutHandler;
    private validSpinnerTypes;
    private validPositions;
    private validDirections;
    private _showForeground;
    private _showBackground;
    private _foregroundClosing;
    private _backgroundClosing;
    showForeground: Observable<boolean>;
    showBackground: Observable<boolean>;
    foregroundClosing: Observable<boolean>;
    backgroundClosing: Observable<boolean>;
    /**
     * Constructor
     * @param config
     */
    constructor(config: NgxUiLoaderConfig);
    /**
     * Get default loader configuration
     * @returns default configuration object
     */
    getDefaultConfig(): NgxUiLoaderConfig;
    /**
     * Get current status
     * @returns An object with waiting foreground and background properties
     */
    getStatus(): {
        waitingForeground: any;
        waitingBackground: any;
    };
    /**
     * Determine whether the loader is active
     * @returns true if the loader is active
     */
    private isActive();
    /**
     * Check whether the queue has any waiting foreground loader
     * @returns true if at least one waiting foreground loader exists
     */
    private hasForeground();
    /**
     * Check whether the queue has any waiting background loader
     * @returns true if at least one waiting background loader exists
     */
    private hasBackground();
    /**
     * Start the loading with a specified id.
     * The loading is only closed off when all IDs are called with stop() method.
     * @param id the optional id of the loading. id is set to 'default' by default.
     * @param foreground is optional. If true, start foreground loading. Otherwise, start background loading.
     */
    start(id?: string, foreground?: boolean): Object;
    /**
     * Stop a foreground loading with specific id
     * @param id the optional id to stop. If not provided, 'default' is used.
     * @returns Object
     */
    stop(id?: string): Object;
    /**
     * Stop a background loading with specific id
     * @param id the optional id to stop. If not provided, 'default' is used.
     * @returns Object
     */
    stopBackground(id?: string): Object;
    /**
     * Validate spinner type. Print out error if it is invalid
     * @param inputName The name of the input property
     * @param value The spinner type to verify
     * @param defaultValue The default spinner type
     * @returns a valid spinner type
     */
    validateSpinnerType(inputName: string, value: string, defaultValue: string): string;
    /**
     * Validate position type. Print out error if it is invalid
     * @param inputName The name of the input property
     * @param value The position value to verify
     * @param defaultValue the default position
     * @returns a valid position
     */
    validatePosition(inputName: string, value: string, defaultValue: string): string;
    /**
     * Validate the progress bar direction. Print out error if it is invalid
     * @param inputName the name of the input property
     * @param value the direction to verify
     * @param defaultValue the default direction
     * @returns a valid direction
     */
    validateDirection(inputName: string, value: string, defaultValue: string): string;
    /**
     * Stop all the loadings including foreground and background
     */
    stopAll(): void;
    /**
     * Generic validation. Print out error if the provided value is invalid
     * @param validValues An array of valid values
     * @param inputName The name of the input property
     * @param value The value to verify
     * @param defaultValue The default value
     */
    private validate(validValues, inputName, value, defaultValue);
    /**
     * Manage to close foreground loading
     */
    private foregroundCloseout();
    /**
     * Manage to close background loading
     */
    private backgroundCloseout();
}
