import { Observable } from 'rxjs';
import { NgxUiLoaderHelperService } from './ngx-ui-loader-helper.service';
import { NgxUiLoaderConfig } from './ngx-ui-loader-config';
export declare class NgxUiLoaderService {
    private helperService;
    private _onStart;
    private _onStop;
    private _onStopAll;
    /**
     * Emit when a loading is started
     */
    onStart: Observable<any>;
    /**
     * Emit when a loading is stopped
     */
    onStop: Observable<any>;
    /**
     * Emit when all loadings are stopped
     */
    onStopAll: Observable<any>;
    /**
     * Constructor
     * @param helperService
     */
    constructor(helperService: NgxUiLoaderHelperService);
    /**
     * Get default configuration of the ngx-ui-loader
     * @returns default configuration object
     */
    getDefaultConfig(): NgxUiLoaderConfig;
    /**
     * Get ngx-ui-loader status
     * @returns a object with waiting foreground and background properties
     */
    getStatus(): any;
    /**
     * Start a foreground loading with specific id
     * @param id The optional id to start. The default value is 'default' if not provided.
     */
    start(id?: string): void;
    /**
     * Start a background loading with specific id
     * @param id The optional id to start. The default value is 'default' if not provided.
     */
    startBackground(id?: string): void;
    /**
     * Stop a foreground loading with specific id.
     * @param id The optional id to stop. If not provided, 'default' is used.
     */
    stop(id?: string): void;
    /**
     * Stop a background loading with specific id.
     * @param id The optional id to stop. If not provided, 'default' is used.
     */
    stopBackground(id?: string): void;
    /**
     * Stop all foreground and background loadings
     */
    stopAll(): void;
    /**
     * Helper
     * @param id
     * @param foreground
     */
    private _start(id?, foreground?);
    /**
     * Helper
     * @param id
     * @param foreground
     */
    private _stop(id?, foreground?);
}
